Test Run Failed Tests
setTimeout | 120000 |
open | ../core/TestRunner.html?test=../tests/ErrorCheckingTestSuite.html |
waitForEval | window.htmlTestRunner.testCaseLoaded | true
click | runSuite |
waitForText | testRuns | 3
verifyText | commandPasses | 37
verifyText | testFailures | 1
verifyText | commandFailures | 5
verifyText | commandErrors | 1
verifyAttribute | errorTitle@class | regex:status_failed
verifyAttribute | errorCaseTitle@class | regex:status_failed